summaryrefslogtreecommitdiff
blob: 0fe91a38a0365adfdc4dde17c2a842e9c8d9fc71 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
--- mirror.pl.dist	Thu Apr  3 16:36:50 2003
+++ mirror.pl	Thu Apr  3 16:38:49 2003
@@ -174,10 +174,14 @@
 $dir = &real_dir_from_path( $0 );
 unshift( @INC, $dir );
 
 # Debian GNU/Linux stores mirror.defaults in /etc/mirror
 $debian_defs = '/etc/mirror';
 unshift( @INC, $debian_defs ) if -d $debian_defs;
 
+# Gentoo stores libraries in /usr/lib/mirror-2.9
+$gentoo_libs = '/usr/lib/mirror-2.9';
+unshift( @INC, $gentoo_libs ) if -d $gentoo_libs;
+
 # This, when eval'd, will get the current dir under windows NT/95
 $win_getcwd = 'Win32::GetCwd';
@@ -174,10 +174,14 @@
 unshift( @INC, $dir );
 
-# Debian GNU/Linux stores mirror.defaults in /etc/mirror
+# Debian GNU/Linux and Gentoo store mirror.defaults in /etc/mirror
 $debian_defs = '/etc/mirror';
 unshift( @INC, $debian_defs ) if -d $debian_defs;